@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2012 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -19,31 +19,35 @@
 #include <Python.h>
 #endif
 
+#include "eckit/sql/SQLSession.h"
 #include "odc/IteratorProxy.h"
 #include "odc/SelectIterator.h"
-#include "eckit/sql/SQLSession.h"
 
-namespace eckit { class PathName; }
-namespace eckit { class DataHandle; }
+namespace eckit {
+class PathName;
+}
+namespace eckit {
+class DataHandle;
+}
 
 namespace odc {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class Select
-{
+class Select {
 public:
-	typedef IteratorProxy<SelectIterator,Select,const double> iterator;
-	typedef iterator::Row row;
 
-    Select(const std::string& selectStatement="", bool manageOwnBuffer=true);
-    Select(const std::string& selectStatement, eckit::DataHandle& dh, bool manageOwnBuffer=true);
-    Select(const std::string& selectStatement, const eckit::PathName& path, bool manageOwnBuffer=true);
+    typedef IteratorProxy<SelectIterator, Select, const double> iterator;
+    typedef iterator::Row row;
+
+    Select(const std::string& selectStatement = "", bool manageOwnBuffer = true);
+    Select(const std::string& selectStatement, eckit::DataHandle& dh, bool manageOwnBuffer = true);
+    Select(const std::string& selectStatement, const eckit::PathName& path, bool manageOwnBuffer = true);
 
     // This only exists to disambiguate const char* --> std::string rather than to bool.
-    Select(const std::string& selectStatement, const char* path, bool manageOwnBuffer=true);
+    Select(const std::string& selectStatement, const char* path, bool manageOwnBuffer = true);
 
-	~Select() noexcept(false);
+    ~Select() noexcept(false);
 
 #ifdef SWIGPYTHON
     iterator __iter__() { return iterator(createSelectIterator(selectStatement_)); }
@@ -51,8 +55,8 @@ public:
 
     eckit::sql::SQLDatabase& database();
 
-	iterator begin();
-	const iterator end();
+    iterator begin();
+    const iterator end();
 
     SelectIterator* createSelectIterator(const std::string&);
 
@@ -63,10 +67,10 @@ private:
 
     std::unique_ptr<eckit::DataHandle> ownDH_;
 
-//	std::istream* istream_;
+    //	std::istream* istream_;
 
-	std::string selectStatement_;
-	std::string delimiter_;
+    std::string selectStatement_;
+    std::string delimiter_;
 
     eckit::sql::SQLSession session_;
 
@@ -78,6 +82,6 @@ private:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace odc
+}  // namespace odc
 
 #endif
