@@ -21,12 +21,12 @@ namespace codec {
 // Self registration
 
 namespace {
-    core::IntegerCodecBuilder<CodecConstant> constantBuilder;
-    core::CodecBuilder<CodecConstantString> constantStringBuilder;
-    core::CodecBuilder<CodecLongConstantString> LongConstantStringBuilder;
-}
+core::IntegerCodecBuilder<CodecConstant> constantBuilder;
+core::CodecBuilder<CodecConstantString> constantStringBuilder;
+core::CodecBuilder<CodecLongConstantString> LongConstantStringBuilder;
+}  // namespace
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace codec
-} // namespace odc
+}  // namespace codec
+}  // namespace odc
