@@ -11,9 +11,9 @@
 #ifndef odc_core_codec_String_H
 #define odc_core_codec_String_H
 
-#include "odc/core/Codec.h"
-#include "odc/codec/Integer.h"
 #include "eckit/memory/Zero.h"
+#include "odc/codec/Integer.h"
+#include "odc/core/Codec.h"
 
 namespace odc {
 namespace codec {
@@ -24,16 +24,16 @@ namespace codec {
 ///       normal Writer phase that is then _reencoded_ using Int16String,...
 ///       We should NEVER see 'chars' in the output data.
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 class CodecChars : public core::DataStreamCodec<ByteOrder> {
 
-public: // definitions
+public:  // definitions
 
     constexpr static const char* codec_name() { return "chars"; }
 
-public: // methods
+public:  // methods
 
-    CodecChars(api::ColumnType type, const std::string& name=codec_name());
+    CodecChars(api::ColumnType type, const std::string& name = codec_name());
     ~CodecChars() override {}
 
     using core::DataStreamCodec<ByteOrder>::load;
@@ -41,11 +41,11 @@ public: // methods
     void load(core::DataStream<ByteOrder>& ds) override;
     void save(core::DataStream<ByteOrder>& ds) override;
 
-protected: // methods
+protected:  // methods
 
     std::unique_ptr<core::Codec> clone() override;
 
-private: // methods
+private:  // methods
 
     unsigned char* encode(unsigned char* p, const double& d) override;
     void decode(double* out) override;
@@ -58,9 +58,9 @@ private: // methods
     size_t dataSizeDoubles() const override { return decodedSizeDoubles_; }
     void dataSizeDoubles(size_t count) override { decodedSizeDoubles_ = count; }
 
-    void print(std::ostream &s) const override;
+    void print(std::ostream& s) const override;
 
-protected: // members
+protected:  // members
 
     std::map<std::string, int64_t> stringLookup_;
     std::vector<std::string> strings_;
@@ -71,30 +71,29 @@ protected: // members
 //----------------------------------------------------------------------------------------------------------------------
 
 
-template<typename ByteOrder, typename InternalCodec>
+template <typename ByteOrder, typename InternalCodec>
 class IntStringCodecBase : public CodecChars<ByteOrder> {
 
     static_assert(std::is_same<typename InternalCodec::value_type, int64_t>::value, "Safety check");
     using InternalInt = typename InternalCodec::value_type;
 
-public: // methods
+public:  // methods
 
     IntStringCodecBase(api::ColumnType type, const std::string& name) :
-        CodecChars<ByteOrder>(type, name),
-        intCodec_(api::INTEGER) {
+        CodecChars<ByteOrder>(type, name), intCodec_(api::INTEGER) {
 
-        this->min_ = odc::MDI::integerMDI();
-        this->max_ = this->min_;
+        this->min_          = odc::MDI::integerMDI();
+        this->max_          = this->min_;
         this->missingValue_ = this->min_;
         intCodec_.min(0);
     }
     ~IntStringCodecBase() override {}
 
-private: // methods
+private:  // methods
 
     std::unique_ptr<core::Codec> clone() override {
         std::unique_ptr<core::Codec> cdc = CodecChars<ByteOrder>::clone();
-        auto& c = static_cast<IntStringCodecBase<ByteOrder, InternalCodec>&>(*cdc);
+        auto& c                          = static_cast<IntStringCodecBase<ByteOrder, InternalCodec>&>(*cdc);
         c.intCodec_.min(intCodec_.min());
         c.intCodec_.max(intCodec_.max());
         c.min(this->min());
@@ -119,7 +118,7 @@ private: // methods
         /// n.b. Yes this is ugly. This is a hack into the existing API - and it assumes
         ///      that the double& provided actually is the first element of a longer string.
 
-        size_t len = ::strnlen(reinterpret_cast<const char*>(&d), this->decodedSizeDoubles_*sizeof(double));
+        size_t len = ::strnlen(reinterpret_cast<const char*>(&d), this->decodedSizeDoubles_ * sizeof(double));
         std::string s(reinterpret_cast<const char*>(&d), len);
 
         auto it = this->stringLookup_.find(s);
@@ -144,13 +143,11 @@ private: // methods
         ASSERT(i < long(this->strings_.size()));
         const std::string& s(this->strings_[i]);
 
-        ::memset(out, 0, this->decodedSizeDoubles_*sizeof(double));
-        ::memcpy(reinterpret_cast<char*>(out), &s[0], std::min(s.length(), this->decodedSizeDoubles_*sizeof(double)));
+        ::memset(out, 0, this->decodedSizeDoubles_ * sizeof(double));
+        ::memcpy(reinterpret_cast<char*>(out), &s[0], std::min(s.length(), this->decodedSizeDoubles_ * sizeof(double)));
     }
 
-    void skip() override {
-        static_cast<core::Codec&>(intCodec_).skip();
-    }
+    void skip() override { static_cast<core::Codec&>(intCodec_).skip(); }
 
     using CodecChars<ByteOrder>::load;
     void load(core::DataStream<ByteOrder>& ds) override {
@@ -181,7 +178,8 @@ private: // methods
             this->strings_[index] = s;
 
             if (s.length() != 0) {
-                this->decodedSizeDoubles_ = std::max(this->decodedSizeDoubles_, ((s.length()-1)/sizeof(double))+1);
+                this->decodedSizeDoubles_ =
+                    std::max(this->decodedSizeDoubles_, ((s.length() - 1) / sizeof(double)) + 1);
             }
         }
 
@@ -198,12 +196,12 @@ private: // methods
 
         for (size_t i = 0; i < this->strings_.size(); i++) {
             ds.write(this->strings_[i]);
-            ds.write(static_cast<int32_t>(0)); // "cnt" field is not used.
+            ds.write(static_cast<int32_t>(0));  // "cnt" field is not used.
             ds.write(static_cast<int32_t>(i));
         }
     }
 
-private: // members
+private:  // members
 
     InternalCodec intCodec_;
 };
@@ -211,18 +209,20 @@ private: // members
 //----------------------------------------------------------------------------------------------------------------------
 
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 struct CodecInt8String : public IntStringCodecBase<ByteOrder, CodecInt8<ByteOrder, int64_t>> {
     constexpr static const char* codec_name() { return "int8_string"; }
-    CodecInt8String(api::ColumnType type) : IntStringCodecBase<ByteOrder, CodecInt8<ByteOrder, int64_t>>(type, codec_name()) {}
+    CodecInt8String(api::ColumnType type) :
+        IntStringCodecBase<ByteOrder, CodecInt8<ByteOrder, int64_t>>(type, codec_name()) {}
     ~CodecInt8String() override {}
 };
 
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 struct CodecInt16String : public IntStringCodecBase<ByteOrder, CodecInt16<ByteOrder, int64_t>> {
     constexpr static const char* codec_name() { return "int16_string"; }
-    CodecInt16String(api::ColumnType type) : IntStringCodecBase<ByteOrder, CodecInt16<ByteOrder, int64_t>>(type, codec_name()) {}
+    CodecInt16String(api::ColumnType type) :
+        IntStringCodecBase<ByteOrder, CodecInt16<ByteOrder, int64_t>>(type, codec_name()) {}
     ~CodecInt16String() override {}
 };
 
@@ -231,25 +231,24 @@ struct CodecInt16String : public IntStringCodecBase<ByteOrder, CodecInt16<ByteOr
 
 // Implementation
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 CodecChars<ByteOrder>::CodecChars(api::ColumnType type, const std::string& name) :
-    core::DataStreamCodec<ByteOrder>(name, type),
-    decodedSizeDoubles_(1) {}
+    core::DataStreamCodec<ByteOrder>(name, type), decodedSizeDoubles_(1) {}
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 unsigned char* CodecChars<ByteOrder>::encode(unsigned char* p, const double& s) {
 
     /// n.b. Yes this is ugly. This is a hack into the existing API - and it assumes
     ///      that the double& provided actually is the first element of a longer string.
 
-    memcpy(p, &s, decodedSizeDoubles_*sizeof(double));
-    return p + (decodedSizeDoubles_*sizeof(double));
+    memcpy(p, &s, decodedSizeDoubles_ * sizeof(double));
+    return p + (decodedSizeDoubles_ * sizeof(double));
 }
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::decode(double* out) {
 
-     this->ds().readBytes(out, sizeof(double)*decodedSizeDoubles_);
+    this->ds().readBytes(out, sizeof(double) * decodedSizeDoubles_);
 }
 
 template <typename ByteOrder>
@@ -257,10 +256,10 @@ void CodecChars<ByteOrder>::skip() {
     this->ds().advance(sizeof(double) * decodedSizeDoubles_);
 }
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::gatherStats(const double& v) {
 
-    size_t len = ::strnlen(reinterpret_cast<const char*>(&v), decodedSizeDoubles_*sizeof(double));
+    size_t len = ::strnlen(reinterpret_cast<const char*>(&v), decodedSizeDoubles_ * sizeof(double));
     std::string s(reinterpret_cast<const char*>(&v), len);
 
     if (stringLookup_.find(s) == stringLookup_.end()) {
@@ -277,54 +276,51 @@ void CodecChars<ByteOrder>::gatherStats(const double& v) {
 }
 
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::load(core::DataStream<ByteOrder>& ds) {
     core::DataStreamCodec<ByteOrder>::load(ds);
     int32_t nStrings;
     ds.read(nStrings);
-    ASSERT(nStrings == 0); // No string table stored
+    ASSERT(nStrings == 0);  // No string table stored
 }
 
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::save(core::DataStream<ByteOrder>& ds) {
     // String table only stored in derived int-storing types
     core::DataStreamCodec<ByteOrder>::save(ds);
     ds.write(static_cast<int32_t>(0));
 }
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 std::unique_ptr<core::Codec> CodecChars<ByteOrder>::clone() {
 
     std::unique_ptr<core::Codec> cdc = core::Codec::clone();
-    auto& c = static_cast<CodecChars&>(*cdc);
-    c.stringLookup_ = stringLookup_;
-    c.strings_ = strings_;
-    c.decodedSizeDoubles_ = decodedSizeDoubles_;
+    auto& c                          = static_cast<CodecChars&>(*cdc);
+    c.stringLookup_                  = stringLookup_;
+    c.strings_                       = strings_;
+    c.decodedSizeDoubles_            = decodedSizeDoubles_;
     ASSERT(c.min() == this->min_);
     ASSERT(c.max() == this->max_);
     return cdc;
 }
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::copyStrings(core::Codec& rhs) {
     CodecChars<ByteOrder>* c = dynamic_cast<CodecChars<ByteOrder>*>(&rhs);
     ASSERT(c);
-    strings_ = c->strings_;
+    strings_      = c->strings_;
     stringLookup_ = c->stringLookup_;
 }
 
-template<typename ByteOrder>
+template <typename ByteOrder>
 void CodecChars<ByteOrder>::print(std::ostream& s) const {
-    s << this->name_
-      << ", width=" << (decodedSizeDoubles_ * sizeof(double))
-      << ", #words=" << strings_.size();
+    s << this->name_ << ", width=" << (decodedSizeDoubles_ * sizeof(double)) << ", #words=" << strings_.size();
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace codec
-} // namespace odc
+}  // namespace codec
+}  // namespace odc
 
 #endif
-
