@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2012 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -16,7 +16,13 @@
 
 #include "odc/api/ColumnType.h"
 
-namespace eckit { namespace sql { namespace type { class SQLType; }}}
+namespace eckit {
+namespace sql {
+namespace type {
+class SQLType;
+}
+}  // namespace sql
+}  // namespace eckit
 
 namespace odc {
 namespace sql {
@@ -27,7 +33,7 @@ odc::api::ColumnType sqlToOdbType(const eckit::sql::type::SQLType& t);
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace sql
-} // namespace odc
+}  // namespace sql
+}  // namespace odc
 
 #endif
